@@ -32,8 +32,8 @@ class AssignValuesWidget : public QDialog
     };
 
 public:
-    explicit AssignValuesWidget(GraphDocumentPtr document, QWidget *parent = 0);
-    ~AssignValuesWidget();
+    explicit AssignValuesWidget(GraphDocumentPtr document, QWidget *parent = nullptr);
+    ~AssignValuesWidget() override;
 
 public Q_SLOTS:
     /**
