@@ -1,19 +1,8 @@
 /*
     This file is part of Rocs.
-    Copyright 2012-2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+    SPDX-FileCopyrightText: 2012-2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "dotgrammar.h"
@@ -163,7 +152,7 @@ using boost::spirit::repository::qi::confix;
 
 typedef BOOST_TYPEOF(SKIPPER) skipper_type;
 
-DotGraphParsingHelper* phelper = 0;
+DotGraphParsingHelper* phelper = nullptr;
 
 template <typename Iterator, typename Skipper = space_type>
 struct DotGrammar : boost::spirit::qi::grammar<Iterator, Skipper> {
