@@ -32,18 +32,18 @@ public:
         DataRole                        //!< access to EdgeType object
     };
 
-    explicit EdgeTypeModel(QObject *parent = 0);
-    virtual ~EdgeTypeModel();
+    explicit EdgeTypeModel(QObject *parent = nullptr);
+    ~EdgeTypeModel() override;
     /**
      * Reimplemented from QAbstractListModel::roleNames()
      */
-    virtual QHash<int,QByteArray> roleNames() const Q_DECL_OVERRIDE;
+    QHash<int,QByteArray> roleNames() const override;
     void setDocument(GraphDocumentPtr document);
     EdgeTypePtr type(int index) const;
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) Q_DECL_OVERRIDE;
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
 Q_SIGNALS:
     void edgeChanged(int index);
