@@ -25,7 +25,7 @@ class GRAPHTHEORY_EXPORT NodeTypeStyle : public QObject
     Q_OBJECT
 public:
     NodeTypeStyle();
-    ~NodeTypeStyle();
+    ~NodeTypeStyle() override;
     void setColor(const QColor &color);
     QColor color() const;
     void setVisible(bool visible);
