@@ -1,21 +1,7 @@
 /*
- *  Copyright 2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) version 3, or any
- *  later version accepted by the membership of KDE e.V. (or its
- *  successor approved by the membership of KDE e.V.), which shall
- *  act as a proxy defined in Section 6 of version 3 of the license.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "test_project.h"
@@ -95,7 +81,8 @@ void TestProject::loadSave()
     QVERIFY(project.projectSave());
 
     // Now the documents live in the test dir
-    for (const auto& d : project.codeDocuments()) {
+    const auto docs = project.codeDocuments();
+    for (const auto& d : docs) {
         qDebug() << "Code document path=" << d->url().toLocalFile();
         QVERIFY(d->url().toLocalFile().startsWith(QDir::currentPath()));
     }
@@ -105,7 +92,8 @@ void TestProject::loadSave()
     QCOMPARE(loadedProject.graphDocuments().count(), project.graphDocuments().count());
 
     // After load, they live in the project dir
-    for (const auto& d : loadedProject.codeDocuments()) {
+    const auto loadedDocs = loadedProject.codeDocuments();
+    for (const auto& d : loadedDocs) {
         qDebug() << "Code document path=" << d->url().toLocalFile();
         QVERIFY(d->url().toLocalFile().startsWith(loadedProject.workingDir()));
     }
