@@ -1,21 +1,7 @@
 /*
- *  Copyright 2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) version 3, or any
- *  later version accepted by the membership of KDE e.V. (or its
- *  successor approved by the membership of KDE e.V.), which shall
- *  act as a proxy defined in Section 6 of version 3 of the license.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "nodetypesdelegate.h"
@@ -52,7 +38,7 @@ void NodeTypesDelegate::paint(QPainter* painter, const QStyleOptionViewItem &opt
     if (!index.isValid()) {
         return;
     }
-    QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, 0);
+    QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, nullptr);
 }
 
 QSize NodeTypesDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
@@ -142,7 +128,7 @@ void NodeTypesDelegate::onColorChanged(const QColor &color)
 {
     // use temporary stored index, since focusedIndex() does not return current index
     // reason: the color dialog signal does not allow for correct index estimation
-    emit colorChanged(m_workaroundColorButtonIndex, color);
+    Q_EMIT colorChanged(m_workaroundColorButtonIndex, color);
 }
 
 void NodeTypesDelegate::onColorDialogOpened()
@@ -153,14 +139,14 @@ void NodeTypesDelegate::onColorDialogOpened()
 void NodeTypesDelegate::onNameChanged(const QString &name)
 {
     QModelIndex index = focusedIndex();
-    emit nameChanged(index, name);
+    Q_EMIT nameChanged(index, name);
 }
 
 void NodeTypesDelegate::showPropertiesDialog()
 {
     QModelIndex index = focusedIndex();
     NodeType *type = qobject_cast<NodeType*>(index.data(NodeTypeModel::DataRole).value<QObject*>());
-    QPointer<NodeTypeProperties> dialog = new NodeTypeProperties(0);
+    QPointer<NodeTypeProperties> dialog = new NodeTypeProperties(nullptr);
     dialog->setType(type->self());
     dialog->exec();
     dialog->deleteLater();
